%% ``The contents of this file are subject to the Erlang Public License,
%% Version 1.0, (the "License"); you may not use this file except in
%% compliance with the License. You may obtain a copy of the License at
%% http://www.erlang.org/EPL1_0.txt
%% 
%% Software distributed under the License is distributed on an "AS IS"
%% basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
%% the License for the specific language governing rights and limitations
%% under the License.
%% 
%% The Original Code is Erlang-4.7.3, December, 1998.
%% 
%% The Initial Developer of the Original Code is Ericsson Telecom
%% AB. Portions created by Ericsson are Copyright (C), 1998, Ericsson
%% Telecom AB. All Rights Reserved.
%% 
%% Contributor(s): ______________________________________.''
%%
%%%----------------------------------------------------------------------
%%% File    : dbg_ui_data_struct.hrl
%%% Author  : Stefan Anbratt <stefan@erlang.ericsson.se>
%%% Purpose : This header file contains the record for the modules
%%%           dbg_ui_view and dbg_ui_trace.
%%% Created : 16 Feb 1998 by Stefan Anbratt <stefan@erlang.ericsson.se>
%%%----------------------------------------------------------------------

-author('stefan@erlang.ericsson.se').


-record(trace,{meta,         % The pid of the process attaching the traced pid
	       pid,          % The pid we are tracing
	       cm,           % The current module being shown in the window
	       cm_obsolete,  % true=current module needs reload, otherwise not.

	       %% State of the traced Pid:
	       state,        % The state of the executing process
			     % One of ?DEAD, ?RUNNING, ?BREAK, ?WAIT
	       reason,	     % If state is ?DEAD, this is the EXIT reason
	       s_module,     % If state is ?BREAK or ?WAIT, this is the module
	       s_line,       % If state is?BREAK or ?WAIT, this is the line

	       cmd_no,       % Dummy variable
	       trace,        % Trace Frame in attach window status
	       bind,         % Bind Frame in attach window status
	       button,       % Button Frame in attach window status
	       eval,         % Eval Frame in attach window status
	       breaks,       % Breaks in the CM
	       stack,        % Stack Pointer
	       stack_flag,   % Stack flag status
	       btrace,       % Back Trace value
	       size,         % {Width,Height} of the window
	       win,          % Window Identifier
	       coords,       % Mouse pointer position
	       line,         % The line in the display editor
	       dir,          % Last int dir
	       mods,         % Modules which are trace compiled
	       btn_press,    % Last time the editor had a buttonpress
	       edt_marked}). % Row in editor has been marked


%% These are the states we assume that a process can be in.
%%

-define(DEAD, pid_dead).
-define(RUNNING, pid_running).
-define(BREAK, pid_at_break).
-define(WAIT, pid_waiting).

%%
%% Empty stack

-define(EMPTY_STACK, {1,1}).
